@@ -204,31 +204,22 @@ extern int pthread_mutexattr_settype(pthread_mutexattr_t* attr, int type);
 
 #include "grib_api.h"
 
-#define GRIB_UNKNOWN_VALUE -9999.999
-#define GRIB_KEY_UNDEF "undef"
-
-#define GRIB_HANDLE_BIG_ECMWF_GRIB1 1
-
 #define MAX_ACCESSOR_ATTRIBUTES 20
 #define MAX_FILE_HANDLES_WITH_MULTI 10
 #define ACCESSORS_ARRAY_SIZE 5000
 #define MAX_NUM_CONCEPTS 2000
 #define MAX_NUM_HASH_ARRAY 2000
 
-#define GRIB_NAMESPACE 10
+#define CODES_NAMESPACE   10
 #define MAX_NAMESPACE_LEN 64
 
-#define GRIB_MY_BUFFER 0
-#define GRIB_USER_BUFFER 1
+#define CODES_MY_BUFFER   0
+#define CODES_USER_BUFFER 1
 
-#define GRIB_REAL_MODE4 4
-#define GRIB_REAL_MODE8 8
+#define CODES_REAL_MODE8 8
 
 #define MAX_NUM_SECTIONS 12
 
-#define GRIB_DISPOSABLE_MEMORY 0
-#define GRIB_LONG_LASTING_MEMORY 1
-
 #define GRIB_LOG_PERROR (1 << 10)
 
 #define GRIB_HASH_ARRAY_TYPE_UNKNOWN 0
@@ -236,17 +227,17 @@ extern int pthread_mutexattr_settype(pthread_mutexattr_t* attr, int type);
 #define GRIB_HASH_ARRAY_TYPE_DOUBLE 2
 #define GRIB_HASH_ARRAY_TYPE_STRING 3
 
-#define CODES_GRIB 1
-#define CODES_BUFR 2
+#define CODES_GRIB  1
+#define CODES_BUFR  2
 #define CODES_METAR 3
-#define CODES_GTS 4
+#define CODES_GTS   4
 
 #define CODES_BUFR_UNPACK_STRUCTURE 0
-#define CODES_BUFR_UNPACK_FLAT 1
-#define CODES_BUFR_NEW_DATA 2
+#define CODES_BUFR_UNPACK_FLAT      1
+#define CODES_BUFR_NEW_DATA         2
 
 #define MAX_SMART_TABLE_COLUMNS 20
-#define MAX_CODETABLE_ENTRIES 65536
+#define MAX_CODETABLE_ENTRIES   65536
 
 /* ACCESSOR COMPARE FLAGS */
 #define GRIB_COMPARE_NAMES (1 << 0)
@@ -327,7 +318,6 @@ typedef void (*accessor_resize_proc)(grib_accessor*, size_t);
 typedef grib_accessor* (*accessor_next_proc)(grib_accessor*, int);
 typedef grib_section* (*accessor_sub_section_proc)(grib_accessor*);
 
-
 typedef int (*accessor_pack_missing_proc)(grib_accessor*);
 typedef int (*accessor_pack_is_missing_proc)(grib_accessor*);
 typedef int (*accessor_pack_long_proc)(grib_accessor*, const long*, size_t* len);
@@ -363,7 +353,6 @@ typedef int (*grib_binop_string_proc)(char*, char*);
 typedef struct second_order_packed second_order_packed;
 typedef void grib_expression_visit_proc(void* udata, grib_expression* e);
 
-
 struct grib_key_value_list
 {
     const char* name;
@@ -378,7 +367,6 @@ struct grib_key_value_list
     grib_key_value_list* next;
 };
 
-
 struct second_order_packed
 {
     unsigned long nbits_per_widths;
@@ -403,9 +391,7 @@ struct grib_packer
     grib_unpack_proc unpack; /** < unpacking procedure                    */
 };
 
-
 /* --------------- */
-
 typedef struct grib_loader grib_loader;
 typedef int (*grib_loader_init_accessor_proc)(grib_loader*, grib_accessor*, grib_arguments*);
 typedef int (*grib_loader_lookup_long_proc)(grib_context*, grib_loader*, const char* name, long* value);
@@ -451,7 +437,6 @@ struct grib_accessors_list
     grib_accessors_list* last;
 };
 
-
 typedef int (*action_create_accessors_handle_proc)(grib_section* p, grib_action* a, grib_loader* h);
 typedef int (*action_notify_change_proc)(grib_action* a, grib_accessor* observer, grib_accessor* observed);
 
@@ -490,7 +475,6 @@ struct grib_action_class
     action_execute_proc execute;
 };
 
-
 /**
 *  a buffer
 *  Structure containing the data of a message
@@ -548,8 +532,6 @@ struct grib_accessor
 
     grib_accessor* same;        /** < accessors with the same name */
     long loop;                  /** < used in lists */
-    long bufr_subset_number;    /** < bufr subset (bufr data accessors belong to different subsets)*/
-    long bufr_group_number;     /** < used in bufr */
     grib_virtual_value* vvalue; /** < virtual value used when transient flag on **/
     const char* set;
     grib_accessor* attributes[MAX_ACCESSOR_ATTRIBUTES]; /** < attributes are accessors */
@@ -574,6 +556,7 @@ struct grib_accessor
 #define GRIB_ACCESSOR_FLAG_DOUBLE_TYPE      (1 << 16)
 #define GRIB_ACCESSOR_FLAG_LOWERCASE        (1 << 17)
 #define GRIB_ACCESSOR_FLAG_BUFR_COORD       (1 << 18)
+#define GRIB_ACCESSOR_FLAG_COPY_IF_CHANGING_EDITION (1 << 19)
 
 /**
 *  a section accessor
@@ -591,7 +574,6 @@ struct grib_section
     size_t padding;
 };
 
-
 struct grib_iterator_class
 {
     grib_iterator_class** super;
@@ -626,10 +608,6 @@ struct grib_nearest_class
 };
 
 /* --------------- */
-/* --------------- */
-typedef void (*search_all_callback_proc)(grib_accessor*, void* data);
-/* --------------- */
-
 typedef int (*dumper_init_proc)(grib_dumper*);
 typedef void (*dumper_dump_proc)(grib_dumper*, grib_accessor*, const char* comment);
 typedef void (*dumper_dump_section_proc)(grib_dumper*, grib_accessor*, grib_block_of_accessors* block);
@@ -714,7 +692,6 @@ typedef struct grib_trie_with_rank_list grib_trie_with_rank_list;
 typedef struct grib_trie_with_rank grib_trie_with_rank;
 typedef struct grib_itrie grib_itrie;
 
-
 /* Dynamic array of strings */
 struct grib_sarray
 {
@@ -851,7 +828,6 @@ struct codes_condition
     double rightDouble;
 };
 
-
 void codes_assertion_failed(const char* message, const char* file, int line);
 
 #define MAX_SET_VALUES 10
@@ -861,9 +837,8 @@ struct grib_handle
 {
     grib_context* context;         /** < context attached to this handle    */
     grib_buffer* buffer;           /** < buffer attached to the handle      */
-    grib_section* root;            /**  the root      section*/
-    grib_section* asserts;         /** the assertion section*/
-    grib_section* rules;           /** the rules     section*/
+    grib_section* root;            /**  the root section*/
+    grib_section* rules;           /** the rules section*/
     grib_dependency* dependencies; /** List of dependencies */
     grib_handle* main;             /** Used during reparsing */
     grib_handle* kid;              /** Used during reparsing */
@@ -871,7 +846,6 @@ struct grib_handle
     int values_stack;
     const grib_values* values[MAX_SET_VALUES]; /** Used when setting multiple values at once */
     size_t values_count[MAX_SET_VALUES];       /** Used when setting multiple values at once */
-    int dont_trigger;                          /** Don't notify triggers */
     int partial;                               /** Not a complete message (just headers) */
     int header_mode;                           /** Header not jet complete */
     char* gts_header;
@@ -883,11 +857,7 @@ struct grib_handle
     char* section_length[MAX_NUM_SECTIONS];
     int sections_count;
     off_t offset;
-    long bufr_subset_number; /* bufr subset number */
-    long bufr_group_number;  /* used in bufr */
     /* grib_accessor* groups[MAX_NUM_GROUPS]; */
-    long missingValueLong;
-    double missingValueDouble;
     ProductKind product_kind;
     /* grib_trie* bufr_elements_table; */
 };
@@ -1561,33 +1531,3 @@ typedef struct j2k_encode_helper
 
 #endif
 
-/* This part is automatically generated by ./errors.pl, do not edit */
-#ifndef grib_errors_internal_H
-#define grib_errors_internal_H
-/** Value mismatch */
-#define GRIB_VALUE_MISMATCH 1
-/** double values are different */
-#define GRIB_DOUBLE_VALUE_MISMATCH 2
-/** long values are different */
-#define GRIB_LONG_VALUE_MISMATCH 3
-/** byte values are different */
-#define GRIB_BYTE_VALUE_MISMATCH 4
-/** string values are different */
-#define GRIB_STRING_VALUE_MISMATCH 5
-/** Offset mismatch */
-#define GRIB_OFFSET_MISMATCH 6
-/** Count mismatch */
-#define GRIB_COUNT_MISMATCH 7
-/** Name mismatch */
-#define GRIB_NAME_MISMATCH 8
-/** Type mismatch */
-#define GRIB_TYPE_MISMATCH 9
-/** Type and value mismatch */
-#define GRIB_TYPE_AND_VALUE_MISMATCH 10
-/** Unable to compare accessors */
-#define GRIB_UNABLE_TO_COMPARE_ACCESSORS 11
-/** Unable to reset iterator */
-#define GRIB_UNABLE_TO_RESET_ITERATOR 12
-/** Assertion failure */
-#define GRIB_ASSERTION_FAILURE 13
-#endif
